Pano contributors (sorted alphabetically)
=========================================

* **[David Barton](https://github.com/davidbarton)**
* **[Michal Baumgartner](https://github.com/m1so)**
* **[Vaclav Bohac](https://github.com/vaclavbohac)**
* **[Mike Christopher](https://github.com/mchristopher)**
* **[Max Cobert](https://github.com/maxcobert)**
* **[Daniel Dotsenko](https://github.com/dvdotsenko)**
* **[Tomas Kislan](https://github.com/tkislan)**
* **[Adam Kovari](https://github.com/akovari)**
* **[Mark Nemec](https://github.com/mrknmc)**
* **[Tomáš Plešek](https://github.com/baldman)**
* **[Lukas Polak](https://github.com/polakluk)**
* **[Roman Roštár](https://github.com/raethlo)**
* **[Vojta Udrzal](https://github.com/froxCZ)**
* **[Mato Vetrak](https://github.com/vetyy)**

**[Full contributors list](https://github.com/panoramichq/panoramic-cli/contributors).**
